const showLog = false;
function log() {
    showLog && console.log.apply(console, arguments);
}

// note this gets called on extension install + update, but also on chrome update.
function recordInstall(currentAppVersion, currentTime, appNameCode) {

    // They may have existing values. So, we request them.
    chrome.storage.sync.get({
        "appVersionHistory": [],
        "initialAppInstallTime": currentTime
    }, savedVals => {

        // Add the current version to the user's history, if not already there.
        const versions = savedVals.appVersionHistory;
        if (!versions.includes(currentAppVersion)) {
            versions.push(currentAppVersion);
        }

        // Now we write the values back, likely setting them for the first time.
        chrome.storage.sync.set({
            "appVersionHistory": versions,
            "initialAppInstallTime": savedVals.initialAppInstallTime,
            "mostRecentUpdateTime": currentTime,
        }, values => {

        });

        const queryArgs = [
            `app=${encodeURIComponent(appNameCode)}`,
            `installTime=${encodeURIComponent(savedVals.initialAppInstallTime)}`,
            `updateTime=${encodeURIComponent(currentTime)}`,
            `vh=${encodeURIComponent(versions.join(','))}`
        ];

        let url = 'http://rehfeld.us/browser-extensions/uninstall-survey.php?' + queryArgs.join('&');
        log("setUninstallURL", url);
        chrome.runtime.setUninstallURL(url);
    });
}

chrome.runtime.onInstalled.addListener(details => {
    log("onInstall", details);
    const manifest = chrome.runtime.getManifest();
    recordInstall(manifest.version, unixTimestamp(), manifest.extNameCode);
});

function unixTimestamp() {
    return Math.floor(Date.now() / 1000);
}